####Study of growth in children -males and females-####

##Reading and transforming data

GROWTH<-read.csv2("growth_mult.csv", header=T)
attach(GROWTH)

require(reshape)
GROWTH<-melt(GROWTH, id = c("PERSON", "SEX"))
GROWTH<-rename(GROWTH, c(variable = "AGE", value = "DISTANCE"))
GROWTH[with(GROWTH, order(PERSON, AGE)),] #this is not necessary for computations

xtabs(DISTANCE~AGE+SEX,GROWTH)/xtabs(~AGE+SEX,GROWTH)

library(lattice)
dotplot(DISTANCE~AGE|SEX,GROWTH)

##Age and sex as factors with interaction, person random

require(nlme)
summary(MODF1<-lme(DISTANCE~AGE*SEX,GROWTH,random=~1|PERSON))
anova(MODF1)

#Estimation of fixed effects and imputation of random effects
fixef(MODF1)
ranef(MODF1)

#Validation plots 
plot(MODF1)
qqnorm(MODF1)

#Comparison of means of fixed factors - Tukey test
require(multcomp)
summary(glht(MODF1, linfct=mcp(SEX="Tukey")))
summary(glht(MODF1, linfct=mcp(AGE="Tukey")))

##Age and sex as factors, person random

summary(MODF2<-lme(DISTANCE~AGE+SEX,GROWTH,random=~1|PERSON))
anova(MODF2)

#Estimation of fixed effects and imputation of random effects
fixef(MODF2)
ranef(MODF2)

#Validation plots 
plot(MODF2)
qqnorm(MODF2)

#Comparison of meas of fixed factors - Tukey test
summary(glht(MODF2, linfct=mcp(SEX="Tukey")))
summary(glht(MODF2, linfct=mcp(AGE="Tukey")))

#Comparison of MODF1 and MODF2
MODF1.ml<-update(MODF1, method="ML")
MODF2.ml<-update(MODF2, method="ML")
anova(MODF1.ml, MODF2.ml)


##Representing data with age as a number

GROWTH$AGE<-as.numeric(gsub("Y", "", GROWTH$AGE))

GROWTH<-groupedData(DISTANCE~AGE|PERSON,GROWTH)
plot(GROWTH)

#library(lattice)
xyplot(DISTANCE~AGE|SEX,GROWTH,type=c("o","g"),groups=PERSON)

##Age as regressor, person random affecting the intercept

summary(MODR1<-lme(DISTANCE~AGE,GROWTH,random=~1|PERSON)) 
anova(MODR1)

#Validation plots 
plot(MODR1)
qqnorm(MODR1)

##Age as regressor in interaction with sex, person random affecting the intercept 

summary(MODR2<-lme(DISTANCE~AGE*SEX,GROWTH,random=~1|PERSON)) 
anova(MODR2)

#Validation plots 
plot(MODR2)
qqnorm(MODR2)

#Imputation of random effects
ranef(MODR2)

##Age as regressor in interaction with sex, person random affecting the intercept 
#compound symmetry

summary(MODE1<-gls(DISTANCE~AGE*SEX,GROWTH,correlation=corCompSymm(form=~1|PERSON))) 
anova(MODE1)
plot(MODE1)
qqnorm(MODE1)

detach(GROWTH)

q()


