#### RANDOM BLOCK DESIGN 
#### Penicillin example

#Reading and writting the data
PENICILLIN<-read.csv2("penicillin.csv", header=T)
attach(PENICILLIN)
write.table(PENICILLIN, quote=F)
str(PENICILLIN)


#Some plots
plot(YIELD~TRT); dev.new()
plot(YIELD~BLEND); dev.new()
interaction.plot(PENICILLIN$TRT,PENICILLIN$BLEND,PENICILLIN$YIELD); dev.new()
interaction.plot(PENICILLIN$BLEND,PENICILLIN$TRT,PENICILLIN$YIELD)

#One way anova
#Testing H0, i.e., population means are equal
PENICILLIN.AOV<-aov(YIELD~TRT, PENICILLIN)
#Examine the ANOVA table
anova(PENICILLIN.AOV)
summary.lm(aov(YIELD~TRT))

#ANOVA diagnostics with 4 graphs/page
layout(matrix(c(1,2,3,4),2,2))  
plot(PENICILLIN.AOV)

#Table of descriptive statistics
print(model.tables(PENICILLIN.AOV,"means"))   
N<-tapply(YIELD, TRT, length)
M<-tapply(YIELD, TRT, mean)
SD<-tapply(YIELD, TRT, sd)
cbind(N=N, Mean=M, Std.dev=SD)

#Post-hoc Tukeys test to investigate pairwise mean
#differences between groups (treatments)
library(multcomp)
summary(glht(PENICILLIN.AOV, linfct=mcp (TRT="Tukey")))

library(agricolae)
HSD.test(PENICILLIN.AOV, "TRT")

#Randomized blocks
#Testing H0, i.e., population means are equal
PENICILLIN.AOV.RB<-aov(YIELD~TRT+BLEND, PENICILLIN)
#Examine the ANOVA table
anova(PENICILLIN.AOV.RB)
summary.lm(aov(YIELD~TRT+BLEND))

#Anova diagnostics
qqnorm(PENICILLIN.AOV.RB$res); dev.new()
plot(PENICILLIN.AOV.RB$fitted,PENICILLIN.AOV.RB$res,xlab="Fitted",ylab="Residuals")

#Post-hoc Tukeys test to investigate pairwise mean
#differences between groups (treatments)
library(multcomp)
summary(glht(PENICILLIN.AOV.RB, linfct=mcp (TRT="Tukey")))

HSD.test(PENICILLIN.AOV.RB, "TRT")

##BLEND random
library(nlme)
summary(MODMIX<-lme(YIELD~TRT,PENICILLIN,random=~1|BLEND))
anova(MODMIX)

#Effect of one missing cell
anova(aov(YIELD~BLEND+TRT,PENICILLIN[-1,]))
anova(aov(YIELD~TRT+BLEND,PENICILLIN[-1,]))

q()


